@@ -89,7 +89,8 @@ class WeakNetworkConfig(object):
                 raise Exception('get_device_ip:{} timeout:{}'.format(serial, timeout))
             ret = self._stf.toggleAndroidWifi(serial, "1", wifiname=self._wifi_name, wifipass=self._wifi_password)
             logger.info("get toggleAndroidWifi response :{}".format(ret))
-            ip = ret.get("ip", None)
+            ip = self._stf.get_android_device_ip(serial)
+            logger.info("get_android_device_ip :{} return ip :{}".format(serial, ip))
             if str(ip).startswith("192.168.0"):
                 self.set_auth(ip)
                 return ip
@@ -137,14 +138,26 @@ class WeakNetworkConfig(object):
         self.bundle_id = self._stf.find_ios_bundle_id(serial, WeakNetworkConfig.IOS_APP_BUNDLE_ID)
         device = self._get_device_info(serial)
         if self.bundle_id is None or device is None:
-            raise Exception('No iOS app bundle:{} found'.format(WeakNetworkConfig.IOS_APP_BUNDLE_ID))
-        self._stf.stop_ios_app(device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
-        self._stf.launch_ios_app(device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID, args=['disconnect'])
-        time.sleep(10)
-        device_ip = self._stf.get_device_ip(device['wda_url'], self.platform)
-        logger.info("get device_ip {}".format(device_ip))
-        if device_ip.startswith('192.168.0') is False:
-            return True
+            logger.error('No iOS app bundle:{} found'.format(WeakNetworkConfig.IOS_APP_BUNDLE_ID))
+        self._stf.stop_ios_app(device['wda_url'], self.bundle_id)
+        self._stf.launch_ios_app(device['wda_url'], self.bundle_id, args=['disconnect'])
+        timeout = 2 * 60
+        t1 = time.time()
+        while True:
+            if time.time() - t1 > timeout:
+                logger.error('get_device_ip:{} timeout:{} 断开弱网连接失败'.format(device['wda_url'], timeout))
+                break
+            device_ip = self._stf.get_device_ip(device['wda_url'], self.platform)
+            logger.info("get device_ip {}".format(device_ip))
+            if device_ip:
+                # 弱网断网现在是192.168.0 如果网段变化则需要修改下面的逻辑
+                if not device_ip.startswith('192.168.0'):
+                    logger.info("device:{} 断开弱网连接".format(serial))
+                    break
+                else:
+                    time.sleep(1)
+            else:
+                time.sleep(1)
 
     def set_auth(self, device_ip):
         url = "{host}{uri}".format(host=self._atc_host,
@@ -175,4 +188,4 @@ class WeakNetworkConfig(object):
             else:
                 return False
         except Exception as e:
-            return False
\ No newline at end of file
+            return False
